@@ -8,10 +8,7 @@ import platform
 
 import ibm_db
 import config
-if sys.version_info >=(3,3 ):
-    from io import StringIO
-else:
-    from io import StringIO
+from io import StringIO
 
 class IbmDbTestFunctions(unittest.TestCase):
     prepconn = ibm_db.connect(config.database, config.user, config.password)
@@ -38,6 +35,7 @@ class IbmDbTestFunctions(unittest.TestCase):
 		fileName.startswith('ibm_db_tests/test_005') or \
                 fileName.startswith('ibm_db_tests/test_018') or \
                 fileName.startswith('ibm_db_tests/test_019') or \
+                fileName.startswith('ibm_db_tests/test_024') or \
                 fileName.startswith('ibm_db_tests/test_053') or \
                 fileName.startswith('ibm_db_tests/test_054') or \
                 fileName.startswith('ibm_db_tests/test_080') or \
